@@ -3,8 +3,7 @@ logLik.grpreg <- function(object, df.method=c("default","active"), REML=FALSE, .
   df.method <- match.arg(df.method)
   n <- as.numeric(object$n)
   df <- if (df.method=="active") apply(coef(object)!=0, 2, sum) else object$df
-  if (object$family=="gaussian")
-  {
+  if (object$family=="gaussian") {
     rdf <- if (REML) n-df else n
     RSS <- object$loss
     l <- -n/2 * (log(2*pi) + log(RSS) - log(rdf)) - rdf/2
