@@ -35,6 +35,20 @@ test_that("grpreg handles constant columns", {
   fit <- grpreg(X, yy, group, penalty="gMCP", family="binomial")
 })
 
+test_that("grpreg handles groups of non-full rank", {
+  n <- 50
+  group <- rep(0:3,4:1)
+  p <- length(group)
+  X <- matrix(rnorm(n*p),ncol=p)
+  X[,7] <- X[,6]
+  y <- rnorm(n)
+  yy <- y > 0
+  fit <- grpreg(X, y, group, penalty="grLasso"); plot(fit)
+  fit <- grpreg(X, y, group, penalty="gMCP"); plot(fit)
+  fit <- grpreg(X, yy, group, penalty="grLasso", family="binomial"); plot(fit)
+  fit <- grpreg(X, yy, group, penalty="gMCP", family="binomial"); plot(fit)
+})
+
 test_that("cv.grpreg() seems to work", {
   n <- 50
   group <- rep(1:4,1:4)
